.. pygame_cards documentation master file, created by
   sphinx-quickstart on Sun Aug 28 22:27:03 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pygame_cards's documentation!
========================================



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
